@@ -5,7 +5,5 @@ from markdown import markdown
 
 
 class MarkdownAdaptor(BasicAdaptor):
-    ADAPTOR_NAME = "markdown"
-
-    def display_value(self) -> str:
+    def display_value(self):
         return format_html(markdown(self.db_value()))
